EXPORTS
	??0TNegotiatedUmtsQoSParameters@@QAE@XZ @ 1 NONAME ; TNegotiatedUmtsQoSParameters::TNegotiatedUmtsQoSParameters(void)
	??0TNegotiatedUmtsR5QoSParameters@@QAE@XZ @ 2 NONAME ; TNegotiatedUmtsR5QoSParameters::TNegotiatedUmtsR5QoSParameters(void)
	??0TUmtsQoSParameters@@QAE@XZ @ 3 NONAME ; TUmtsQoSParameters::TUmtsQoSParameters(void)
	??0TUmtsR5QoSParameters@@QAE@XZ @ 4 NONAME ; TUmtsR5QoSParameters::TUmtsR5QoSParameters(void)
	??1CUmtsQoSPolicy@@UAE@XZ @ 5 NONAME ; CUmtsQoSPolicy::~CUmtsQoSPolicy(void)
	??1CUmtsR5QoSPolicy@@UAE@XZ @ 6 NONAME ; CUmtsR5QoSPolicy::~CUmtsR5QoSPolicy(void)
	?Copy@CUmtsQoSPolicy@@UAEHABVCExtensionBase@@@Z @ 7 NONAME ; int CUmtsQoSPolicy::Copy(class CExtensionBase const &)
	?Copy@CUmtsR5QoSPolicy@@UAEHABVCExtensionBase@@@Z @ 8 NONAME ; int CUmtsR5QoSPolicy::Copy(class CExtensionBase const &)
	?CreateL@CUmtsQoSPolicy@@UAEPAVCExtensionBase@@XZ @ 9 NONAME ; class CExtensionBase * CUmtsQoSPolicy::CreateL(void)
	?CreateL@CUmtsR5QoSPolicy@@UAEPAVCExtensionBase@@XZ @ 10 NONAME ; class CExtensionBase * CUmtsR5QoSPolicy::CreateL(void)
	?Data@CUmtsQoSPolicy@@UAEAAVTDesC8@@XZ @ 11 NONAME ; class TDesC8 & CUmtsQoSPolicy::Data(void)
	?Data@CUmtsR5QoSPolicy@@UAEAAVTDesC8@@XZ @ 12 NONAME ; class TDesC8 & CUmtsR5QoSPolicy::Data(void)
	?DeliveryOfErroneusSdu@TUmtsQoSParameters@@QBE?AW4TUmtsErroneousSDUDelivery@@XZ @ 13 NONAME ; enum TUmtsErroneousSDUDelivery TUmtsQoSParameters::DeliveryOfErroneusSdu(void) const
	?DeliveryOrder@TUmtsQoSParameters@@QBE?AW4TUmtsDeliveryOrder@@XZ @ 14 NONAME ; enum TUmtsDeliveryOrder TUmtsQoSParameters::DeliveryOrder(void) const
	?ErrorCode@TNegotiatedUmtsQoSParameters@@QBEHXZ @ 15 NONAME ; int TNegotiatedUmtsQoSParameters::ErrorCode(void) const
	?ErrorCode@TNegotiatedUmtsR5QoSParameters@@QBEHXZ @ 16 NONAME ; int TNegotiatedUmtsR5QoSParameters::ErrorCode(void) const
	?ErrorRatio@TUmtsQoSParameters@@QBE?AW4TUmtsSDUErrorRatio@@XZ @ 17 NONAME ; enum TUmtsSDUErrorRatio TUmtsQoSParameters::ErrorRatio(void) const
	?GetQoSMinimum@CUmtsQoSPolicy@@QBEXAAVTUmtsQoSParameters@@@Z @ 18 NONAME ; void CUmtsQoSPolicy::GetQoSMinimum(class TUmtsQoSParameters &) const
	?GetQoSMinimum@CUmtsR5QoSPolicy@@QBEXAAVTUmtsR5QoSParameters@@@Z @ 19 NONAME ; void CUmtsR5QoSPolicy::GetQoSMinimum(class TUmtsR5QoSParameters &) const
	?GetQoSNegotiated@CUmtsQoSPolicy@@QBEXAAVTNegotiatedUmtsQoSParameters@@@Z @ 20 NONAME ; void CUmtsQoSPolicy::GetQoSNegotiated(class TNegotiatedUmtsQoSParameters &) const
	?GetQoSNegotiated@CUmtsR5QoSPolicy@@QBEXAAVTNegotiatedUmtsR5QoSParameters@@@Z @ 21 NONAME ; void CUmtsR5QoSPolicy::GetQoSNegotiated(class TNegotiatedUmtsR5QoSParameters &) const
	?GetQoSRequested@CUmtsQoSPolicy@@QBEXAAVTUmtsQoSParameters@@@Z @ 22 NONAME ; void CUmtsQoSPolicy::GetQoSRequested(class TUmtsQoSParameters &) const
	?GetQoSRequested@CUmtsR5QoSPolicy@@QBEXAAVTUmtsR5QoSParameters@@@Z @ 23 NONAME ; void CUmtsR5QoSPolicy::GetQoSRequested(class TUmtsR5QoSParameters &) const
	?GuaranteedBitrateDownlink@TUmtsQoSParameters@@QBEHXZ @ 24 NONAME ; int TUmtsQoSParameters::GuaranteedBitrateDownlink(void) const
	?GuaranteedBitrateUplink@TUmtsQoSParameters@@QBEHXZ @ 25 NONAME ; int TUmtsQoSParameters::GuaranteedBitrateUplink(void) const
	?HeaderCompression@CUmtsQoSPolicy@@QBEIXZ @ 26 NONAME ; unsigned int CUmtsQoSPolicy::HeaderCompression(void) const
	?HeaderCompression@CUmtsR5QoSPolicy@@QBEIXZ @ 27 NONAME ; unsigned int CUmtsR5QoSPolicy::HeaderCompression(void) const
	?HeaderCompression@TNegotiatedUmtsQoSParameters@@QBEIXZ @ 28 NONAME ; unsigned int TNegotiatedUmtsQoSParameters::HeaderCompression(void) const
	?HeaderCompression@TNegotiatedUmtsR5QoSParameters@@QBEIXZ @ 29 NONAME ; unsigned int TNegotiatedUmtsR5QoSParameters::HeaderCompression(void) const
	?MaxBitrateDownlink@TUmtsQoSParameters@@QBEHXZ @ 30 NONAME ; int TUmtsQoSParameters::MaxBitrateDownlink(void) const
	?MaxBitrateUplink@TUmtsQoSParameters@@QBEHXZ @ 31 NONAME ; int TUmtsQoSParameters::MaxBitrateUplink(void) const
	?MaxSduSize@TUmtsQoSParameters@@QBEHXZ @ 32 NONAME ; int TUmtsQoSParameters::MaxSduSize(void) const
	?NewL@CUmtsQoSPolicy@@SAPAV1@XZ @ 33 NONAME ; class CUmtsQoSPolicy * CUmtsQoSPolicy::NewL(void)
	?NewL@CUmtsR5QoSPolicy@@SAPAV1@XZ @ 34 NONAME ; class CUmtsR5QoSPolicy * CUmtsR5QoSPolicy::NewL(void)
	?ParseMessage@CUmtsQoSPolicy@@UAEHABVTDesC8@@@Z @ 35 NONAME ; int CUmtsQoSPolicy::ParseMessage(class TDesC8 const &)
	?ParseMessage@CUmtsR5QoSPolicy@@UAEHABVTDesC8@@@Z @ 36 NONAME ; int CUmtsR5QoSPolicy::ParseMessage(class TDesC8 const &)
	?Priority@TUmtsQoSParameters@@QBE?AW4TUmtsTrafficHandlingPriority@@XZ @ 37 NONAME ; enum TUmtsTrafficHandlingPriority TUmtsQoSParameters::Priority(void) const
	?ResidualBer@TUmtsQoSParameters@@QBE?AW4TUmtsBitErrorRatio@@XZ @ 38 NONAME ; enum TUmtsBitErrorRatio TUmtsQoSParameters::ResidualBer(void) const
	?SetDeliveryOfErroneusSdu@TUmtsQoSParameters@@QAEHW4TUmtsErroneousSDUDelivery@@@Z @ 39 NONAME ; int TUmtsQoSParameters::SetDeliveryOfErroneusSdu(enum TUmtsErroneousSDUDelivery)
	?SetDeliveryOrder@TUmtsQoSParameters@@QAEHW4TUmtsDeliveryOrder@@@Z @ 40 NONAME ; int TUmtsQoSParameters::SetDeliveryOrder(enum TUmtsDeliveryOrder)
	?SetErrorRatio@TUmtsQoSParameters@@QAEHW4TUmtsSDUErrorRatio@@@Z @ 41 NONAME ; int TUmtsQoSParameters::SetErrorRatio(enum TUmtsSDUErrorRatio)
	?SetGuaranteedBitrateDownlink@TUmtsQoSParameters@@QAEHI@Z @ 42 NONAME ; int TUmtsQoSParameters::SetGuaranteedBitrateDownlink(unsigned int)
	?SetGuaranteedBitrateUplink@TUmtsQoSParameters@@QAEHI@Z @ 43 NONAME ; int TUmtsQoSParameters::SetGuaranteedBitrateUplink(unsigned int)
	?SetHeaderCompression@CUmtsQoSPolicy@@QAEHI@Z @ 44 NONAME ; int CUmtsQoSPolicy::SetHeaderCompression(unsigned int)
	?SetHeaderCompression@CUmtsR5QoSPolicy@@QAEHI@Z @ 45 NONAME ; int CUmtsR5QoSPolicy::SetHeaderCompression(unsigned int)
	?SetMaxBitrateDownlink@TUmtsQoSParameters@@QAEHI@Z @ 46 NONAME ; int TUmtsQoSParameters::SetMaxBitrateDownlink(unsigned int)
	?SetMaxBitrateUplink@TUmtsQoSParameters@@QAEHI@Z @ 47 NONAME ; int TUmtsQoSParameters::SetMaxBitrateUplink(unsigned int)
	?SetMaxSduSize@TUmtsQoSParameters@@QAEHI@Z @ 48 NONAME ; int TUmtsQoSParameters::SetMaxSduSize(unsigned int)
	?SetPriority@TUmtsQoSParameters@@QAEHW4TUmtsTrafficHandlingPriority@@@Z @ 49 NONAME ; int TUmtsQoSParameters::SetPriority(enum TUmtsTrafficHandlingPriority)
	?SetQoSMinimum@CUmtsQoSPolicy@@QAEXABVTUmtsQoSParameters@@@Z @ 50 NONAME ; void CUmtsQoSPolicy::SetQoSMinimum(class TUmtsQoSParameters const &)
	?SetQoSMinimum@CUmtsR5QoSPolicy@@QAEXABVTUmtsR5QoSParameters@@@Z @ 51 NONAME ; void CUmtsR5QoSPolicy::SetQoSMinimum(class TUmtsR5QoSParameters const &)
	?SetQoSRequested@CUmtsQoSPolicy@@QAEXABVTUmtsQoSParameters@@@Z @ 52 NONAME ; void CUmtsQoSPolicy::SetQoSRequested(class TUmtsQoSParameters const &)
	?SetQoSRequested@CUmtsR5QoSPolicy@@QAEXABVTUmtsR5QoSParameters@@@Z @ 53 NONAME ; void CUmtsR5QoSPolicy::SetQoSRequested(class TUmtsR5QoSParameters const &)
	?SetResidualBer@TUmtsQoSParameters@@QAEHW4TUmtsBitErrorRatio@@@Z @ 54 NONAME ; int TUmtsQoSParameters::SetResidualBer(enum TUmtsBitErrorRatio)
	?SetSignallingIndicator@TUmtsR5QoSParameters@@QAEHH@Z @ 55 NONAME ; int TUmtsR5QoSParameters::SetSignallingIndicator(int)
	?SetSourceStatisticsDescriptor@TUmtsR5QoSParameters@@QAEHW4TUmtsSourceStatisticsDescriptor@@@Z @ 56 NONAME ; int TUmtsR5QoSParameters::SetSourceStatisticsDescriptor(enum TUmtsSourceStatisticsDescriptor)
	?SetTrafficClass@TUmtsQoSParameters@@QAEHW4TUmtsTrafficClass@@@Z @ 57 NONAME ; int TUmtsQoSParameters::SetTrafficClass(enum TUmtsTrafficClass)
	?SetTransferDelay@TUmtsQoSParameters@@QAEHI@Z @ 58 NONAME ; int TUmtsQoSParameters::SetTransferDelay(unsigned int)
	?SignallingIndicator@TUmtsR5QoSParameters@@QBEHXZ @ 59 NONAME ; int TUmtsR5QoSParameters::SignallingIndicator(void) const
	?SourceStatisticsDescriptor@TUmtsR5QoSParameters@@QBE?AW4TUmtsSourceStatisticsDescriptor@@XZ @ 60 NONAME ; enum TUmtsSourceStatisticsDescriptor TUmtsR5QoSParameters::SourceStatisticsDescriptor(void) const
	?TrafficClass@TUmtsQoSParameters@@QBE?AW4TUmtsTrafficClass@@XZ @ 61 NONAME ; enum TUmtsTrafficClass TUmtsQoSParameters::TrafficClass(void) const
	?TransferDelay@TUmtsQoSParameters@@QBEHXZ @ 62 NONAME ; int TUmtsQoSParameters::TransferDelay(void) const
	??0TSblpParameters@@QAE@XZ @ 63 NONAME ABSENT ; TSblpParameters::TSblpParameters(void)
	??1CSblpPolicy@@UAE@XZ @ 64 NONAME ; CSblpPolicy::~CSblpPolicy(void)
	??4TSblpParameters@@QAEAAV0@ABV0@@Z @ 65 NONAME ABSENT ; class TSblpParameters & TSblpParameters::operator=(class TSblpParameters const &)
	?Copy@CSblpPolicy@@UAEHABVCExtensionBase@@@Z @ 66 NONAME ; int CSblpPolicy::Copy(class CExtensionBase const &)
	?CreateL@CSblpPolicy@@UAEPAVCExtensionBase@@XZ @ 67 NONAME ; class CExtensionBase * CSblpPolicy::CreateL(void)
	?Data@CSblpPolicy@@UAEAAVTDesC8@@XZ @ 68 NONAME ; class TDesC8 & CSblpPolicy::Data(void)
	?GetFlowId@TSblpParameters@@QAEAAUTFlowIdentifier@1@H@Z @ 69 NONAME ABSENT ; struct TSblpParameters::TFlowIdentifier & TSblpParameters::GetFlowId(int)
	?GetFlowIds@TSblpParameters@@QAEHAAV?$RArray@UTFlowIdentifier@TSblpParameters@@@@@Z @ 70 NONAME ABSENT ; int TSblpParameters::GetFlowIds(class RArray<struct TSblpParameters::TFlowIdentifier> &)
	?GetMAT@TSblpParameters@@QBEHAAV?$TBuf8@$0PP@@@@Z @ 71 NONAME ABSENT ; int TSblpParameters::GetMAT(class TBuf8<255> &) const
	?GetSblpParameters@CSblpPolicy@@QBEXAAVTSblpParameters@@@Z @ 72 NONAME ABSENT ; void CSblpPolicy::GetSblpParameters(class TSblpParameters &) const
	?NewL@CSblpPolicy@@SAPAV1@XZ @ 73 NONAME ; class CSblpPolicy * CSblpPolicy::NewL(void)
	?NrOfFlowIds@TSblpParameters@@QAEHXZ @ 74 NONAME ABSENT ; int TSblpParameters::NrOfFlowIds(void)
	?ParseMessage@CSblpPolicy@@UAEHABVTDesC8@@@Z @ 75 NONAME ; int CSblpPolicy::ParseMessage(class TDesC8 const &)
	?SetFlowIds@TSblpParameters@@QAEXABV?$RArray@UTFlowIdentifier@TSblpParameters@@@@@Z @ 76 NONAME ABSENT ; void TSblpParameters::SetFlowIds(class RArray<struct TSblpParameters::TFlowIdentifier> const &)
	?SetMAT@TSblpParameters@@QAEXABV?$TBuf8@$0PP@@@@Z @ 77 NONAME ABSENT ; void TSblpParameters::SetMAT(class TBuf8<255> const &)
	?SetSblpParameters@CSblpPolicy@@QAEXABVTSblpParameters@@@Z @ 78 NONAME ABSENT ; void CSblpPolicy::SetSblpParameters(class TSblpParameters const &)
	??0TImsParameter@@QAE@XZ @ 79 NONAME ; TImsParameter::TImsParameter(void)
	??1CImsPolicy@@UAE@XZ @ 80 NONAME ; CImsPolicy::~CImsPolicy(void)
	?Copy@CImsPolicy@@UAEHABVCExtensionBase@@@Z @ 81 NONAME ; int CImsPolicy::Copy(class CExtensionBase const &)
	?CreateL@CImsPolicy@@UAEPAVCExtensionBase@@XZ @ 82 NONAME ; class CExtensionBase * CImsPolicy::CreateL(void)
	?Data@CImsPolicy@@UAEAAVTDesC8@@XZ @ 83 NONAME ; class TDesC8 & CImsPolicy::Data(void)
	?GetIMSSigallingIndicator@TImsParameter@@QBEHXZ @ 84 NONAME ; int TImsParameter::GetIMSSigallingIndicator(void) const
	?GetImsParameter@CImsPolicy@@QBEXAAVTImsParameter@@@Z @ 85 NONAME ; void CImsPolicy::GetImsParameter(class TImsParameter &) const
	?NewL@CImsPolicy@@SAPAV1@XZ @ 86 NONAME ; class CImsPolicy * CImsPolicy::NewL(void)
	?ParseMessage@CImsPolicy@@UAEHABVTDesC8@@@Z @ 87 NONAME ; int CImsPolicy::ParseMessage(class TDesC8 const &)
	?SetIMSSigallingIndicator@TImsParameter@@QAEXH@Z @ 88 NONAME ; void TImsParameter::SetIMSSigallingIndicator(int)
	?SetImsParameter@CImsPolicy@@QAEXABVTImsParameter@@@Z @ 89 NONAME ; void CImsPolicy::SetImsParameter(class TImsParameter const &)
	??0CSblpParameters@@QAE@XZ @ 90 NONAME ; CSblpParameters::CSblpParameters(void)
	??1CSblpParameters@@UAE@XZ @ 91 NONAME ; CSblpParameters::~CSblpParameters(void)
	??4CSblpParameters@@QAEAAV0@ABV0@@Z @ 92 NONAME ; class CSblpParameters & CSblpParameters::operator=(class CSblpParameters const &)
	?GetFlowId@CSblpParameters@@QAEAAUTFlowIdentifier@1@H@Z @ 93 NONAME ; struct CSblpParameters::TFlowIdentifier & CSblpParameters::GetFlowId(int)
	?GetFlowIds@CSblpParameters@@QAEHAAV?$RArray@UTFlowIdentifier@CSblpParameters@@@@@Z @ 94 NONAME ; int CSblpParameters::GetFlowIds(class RArray<struct CSblpParameters::TFlowIdentifier> &)
	?GetMAT@CSblpParameters@@QBEHAAV?$TBuf8@$0PP@@@@Z @ 95 NONAME ; int CSblpParameters::GetMAT(class TBuf8<255> &) const
	?GetSblpParameters@CSblpPolicy@@QBEXAAVCSblpParameters@@@Z @ 96 NONAME ; void CSblpPolicy::GetSblpParameters(class CSblpParameters &) const
	?NrOfFlowIds@CSblpParameters@@QAEHXZ @ 97 NONAME ; int CSblpParameters::NrOfFlowIds(void)
	?SetFlowIds@CSblpParameters@@QAEXABV?$RArray@UTFlowIdentifier@CSblpParameters@@@@@Z @ 98 NONAME ; void CSblpParameters::SetFlowIds(class RArray<struct CSblpParameters::TFlowIdentifier> const &)
	?SetMAT@CSblpParameters@@QAEXABV?$TBuf8@$0PP@@@@Z @ 99 NONAME ; void CSblpParameters::SetMAT(class TBuf8<255> const &)
	?SetSblpParameters@CSblpPolicy@@QAEXABVCSblpParameters@@@Z @ 100 NONAME ; void CSblpPolicy::SetSblpParameters(class CSblpParameters const &)

